@@ -24,7 +24,7 @@ class AutomationAgentInfo(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param InstanceId: 实例ID。
         :type InstanceId: str
         :param Version: Agent 版本号。
@@ -35,7 +35,9 @@ class AutomationAgentInfo(AbstractModel):
 <li> Online：在线
 <li> Offline：离线
         :type AgentStatus: str
-        :param Environment: Agent运行环境
+        :param Environment: Agent运行环境，取值范围：
+<li> Linux：Linux实例
+<li> Windows：Windows实例
         :type Environment: str
         """
         self.InstanceId = None
@@ -66,7 +68,7 @@ class Command(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param CommandId: 命令ID。
         :type CommandId: str
         :param CommandName: 命令名称。
@@ -151,7 +153,7 @@ class CommandDocument(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Content: Base64 编码后的执行命令。
         :type Content: str
         :param CommandType: 命令类型。
@@ -191,7 +193,7 @@ class CreateCommandRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param CommandName: 命令名称。名称仅支持中文、英文、数字、下划线、分隔符"-"、小数点，最大长度不能超60个字节。
         :type CommandName: str
         :param Content: Base64编码后的命令内容，长度不可超过64KB。
@@ -219,6 +221,13 @@ key为自定义参数名称，value为该参数的默认取值。kv均为字符
         :param Username: 在 CVM 或 Lighthouse 实例中执行命令的用户名称。
 使用最小权限执行命令是权限管理的最佳实践，建议您以普通用户身份执行云助手命令。默认情况下，在Linux实例中以root用户执行命令。
         :type Username: str
+        :param OutputCOSBucketUrl: 指定日志上传的cos bucket 地址，必须以https开头，如 https://BucketName-123454321.cos.ap-beijing.myqcloud.com。
+        :type OutputCOSBucketUrl: str
+        :param OutputCOSKeyPrefix: 指定日志在cos bucket中的目录，目录命名有如下规则：
+1. 可用数字、中英文和可见字符的组合，长度最多为60。
+2. 用 / 分割路径，可快速创建子目录。
+3. 不允许连续 / ；不允许以 / 开头；不允许以..作为文件夹名称
+        :type OutputCOSKeyPrefix: str
         """
         self.CommandName = None
         self.Content = None
@@ -230,6 +239,8 @@ key为自定义参数名称，value为该参数的默认取值。kv均为字符
         self.DefaultParameters = None
         self.Tags = None
         self.Username = None
+        self.OutputCOSBucketUrl = None
+        self.OutputCOSKeyPrefix = None
 
 
     def _deserialize(self, params):
@@ -248,6 +259,8 @@ key为自定义参数名称，value为该参数的默认取值。kv均为字符
                 obj._deserialize(item)
                 self.Tags.append(obj)
         self.Username = params.get("Username")
+        self.OutputCOSBucketUrl = params.get("OutputCOSBucketUrl")
+        self.OutputCOSKeyPrefix = params.get("OutputCOSKeyPrefix")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -263,7 +276,7 @@ class CreateCommandResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param CommandId: 命令ID。
         :type CommandId: str
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -278,13 +291,84 @@ class CreateCommandResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class CreateInvokerRequest(AbstractModel):
+    """CreateInvoker请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param Name: 执行器名称。
+        :type Name: str
+        :param Type: 执行器类型，当前仅支持周期类型执行器，取值：`SCHEDULE` 。
+        :type Type: str
+        :param CommandId: 远程命令ID。
+        :type CommandId: str
+        :param InstanceIds: 触发器关联的实例ID。列表上限 100。
+        :type InstanceIds: list of str
+        :param Username: 命令执行用户。
+        :type Username: str
+        :param Parameters: 命令自定义参数。
+        :type Parameters: str
+        :param ScheduleSettings: 周期执行器设置，当创建周期执行器时，必须指定此参数。
+        :type ScheduleSettings: :class:`tencentcloud.tat.v20201028.models.ScheduleSettings`
+        """
+        self.Name = None
+        self.Type = None
+        self.CommandId = None
+        self.InstanceIds = None
+        self.Username = None
+        self.Parameters = None
+        self.ScheduleSettings = None
+
+
+    def _deserialize(self, params):
+        self.Name = params.get("Name")
+        self.Type = params.get("Type")
+        self.CommandId = params.get("CommandId")
+        self.InstanceIds = params.get("InstanceIds")
+        self.Username = params.get("Username")
+        self.Parameters = params.get("Parameters")
+        if params.get("ScheduleSettings") is not None:
+            self.ScheduleSettings = ScheduleSettings()
+            self.ScheduleSettings._deserialize(params.get("ScheduleSettings"))
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class CreateInvokerResponse(AbstractModel):
+    """CreateInvoker返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param InvokerId: 执行器ID。
+        :type InvokerId: str
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.InvokerId = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.InvokerId = params.get("InvokerId")
+        self.RequestId = params.get("RequestId")
+
+
 class DeleteCommandRequest(AbstractModel):
     """DeleteCommand请求参数结构体
 
     """
 
     def __init__(self):
-        """
+        r"""
         :param CommandId: 待删除的命令ID。
         :type CommandId: str
         """
@@ -308,7 +392,48 @@ class DeleteCommandResponse(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
         """
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.RequestId = params.get("RequestId")
+
+
+class DeleteInvokerRequest(AbstractModel):
+    """DeleteInvoker请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param InvokerId: 待删除的执行器ID。
+        :type InvokerId: str
+        """
+        self.InvokerId = None
+
+
+    def _deserialize(self, params):
+        self.InvokerId = params.get("InvokerId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class DeleteInvokerResponse(AbstractModel):
+    """DeleteInvoker返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
@@ -325,7 +450,7 @@ class DescribeAutomationAgentStatusRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param InstanceIds: 待查询的实例ID列表。
         :type InstanceIds: list of str
         :param Filters: 过滤条件。<br> <li> agent-status - String - 是否必填：否 -（过滤条件）按照agent状态过滤，取值：Online 在线，Offline 离线。<br> <li> environment - String - 是否必填：否 -（过滤条件）按照agent运行环境查询，取值：Linux。<br> <li> instance-id - String - 是否必填：否 -（过滤条件）按照实例ID过滤。 <br>每次请求的 `Filters` 的上限为10， `Filter.Values` 的上限为5。参数不支持同时指定 `InstanceIds` 和 `Filters` 。
@@ -366,7 +491,7 @@ class DescribeAutomationAgentStatusResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param AutomationAgentSet: Agent 信息列表。
         :type AutomationAgentSet: list of AutomationAgentInfo
         :param TotalCount: 符合条件的 Agent 总数。
@@ -396,13 +521,14 @@ class DescribeCommandsRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param CommandIds: 命令ID列表，每次请求的上限为100。参数不支持同时指定 `CommandIds` 和 `Filters` 。
         :type CommandIds: list of str
         :param Filters: 过滤条件。
 <li> command-id - String - 是否必填：否 -（过滤条件）按照命令ID过滤。
 <li> command-name - String - 是否必填：否 -（过滤条件）按照命令名称过滤。
-<li> created-by - String - 是否必填：否 -（过滤条件）按照命令创建者过滤，取值为 TAT 或 USER，TAT 代表公共命令，USER 代表由用户创建的命令。 
+<li> command-type - String - 是否必填：否 -（过滤条件）按照命令类型过滤，取值为 SHELL 或 POWERSHELL。
+<li> created-by - String - 是否必填：否 -（过滤条件）按照命令创建者过滤，取值为 TAT 或 USER，TAT 代表公共命令，USER 代表由用户创建的命令。
 <li> tag-key - String - 是否必填：否 -（过滤条件）按照标签键进行过滤。</li>
 <li> tag-value - String - 是否必填：否 -（过滤条件）按照标签值进行过滤。</li>
 <li> tag:tag-key - String - 是否必填：否 -（过滤条件）按照标签键值对进行过滤。 tag-key使用具体的标签键进行替换。使用请参考示例4</li>
@@ -445,7 +571,7 @@ class DescribeCommandsResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param TotalCount: 符合条件的命令总数。
         :type TotalCount: int
         :param CommandSet: 命令详情列表。
@@ -475,7 +601,7 @@ class DescribeInvocationTasksRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param InvocationTaskIds: 执行任务ID列表，每次请求的上限为100。参数不支持同时指定 `InvocationTaskIds` 和 `Filters`。
         :type InvocationTaskIds: list of str
         :param Filters: 过滤条件。<br> <li> invocation-id - String - 是否必填：否 -（过滤条件）按照执行活动ID过滤。<br> <li> invocation-task-id - String - 是否必填：否 -（过滤条件）按照执行任务ID过滤。<br> <li> instance-id - String - 是否必填：否 -（过滤条件）按照实例ID过滤。 <br>每次请求的 `Filters` 的上限为10， `Filter.Values` 的上限为5。参数不支持同时指定 `InvocationTaskIds` 和 `Filters` 。
@@ -520,7 +646,7 @@ class DescribeInvocationTasksResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param TotalCount: 符合条件的执行任务总数。
         :type TotalCount: int
         :param InvocationTaskSet: 执行任务列表。
@@ -550,7 +676,7 @@ class DescribeInvocationsRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param InvocationIds: 执行活动ID列表，每次请求的上限为100。参数不支持同时指定 `InvocationIds` 和 `Filters`。
         :type InvocationIds: list of str
         :param Filters: 过滤条件。<br> <li> invocation-id - String - 是否必填：否 -（过滤条件）按照执行活动ID过滤。<br> 
@@ -595,7 +721,7 @@ class DescribeInvocationsResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param TotalCount: 符合条件的执行活动总数。
         :type TotalCount: int
         :param InvocationSet: 执行活动列表。
@@ -619,6 +745,143 @@ class DescribeInvocationsResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class DescribeInvokerRecordsRequest(AbstractModel):
+    """DescribeInvokerRecords请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param InvokerIds: 执行器ID列表。列表上限 100。
+        :type InvokerIds: list of str
+        :param Limit: 返回数量，默认为20，最大值为100。
+        :type Limit: int
+        :param Offset: 偏移量，默认为0。
+        :type Offset: int
+        """
+        self.InvokerIds = None
+        self.Limit = None
+        self.Offset = None
+
+
+    def _deserialize(self, params):
+        self.InvokerIds = params.get("InvokerIds")
+        self.Limit = params.get("Limit")
+        self.Offset = params.get("Offset")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class DescribeInvokerRecordsResponse(AbstractModel):
+    """DescribeInvokerRecords返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param TotalCount: 符合条件的历史记录数量。
+        :type TotalCount: int
+        :param InvokerRecordSet: 执行器执行历史记录。
+        :type InvokerRecordSet: list of InvokerRecord
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.TotalCount = None
+        self.InvokerRecordSet = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.TotalCount = params.get("TotalCount")
+        if params.get("InvokerRecordSet") is not None:
+            self.InvokerRecordSet = []
+            for item in params.get("InvokerRecordSet"):
+                obj = InvokerRecord()
+                obj._deserialize(item)
+                self.InvokerRecordSet.append(obj)
+        self.RequestId = params.get("RequestId")
+
+
+class DescribeInvokersRequest(AbstractModel):
+    """DescribeInvokers请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param InvokerIds: 执行器ID列表。
+        :type InvokerIds: list of str
+        :param Filters: 过滤条件：
+
+<li> invoker-id - String - 是否必填：否 - （过滤条件）按执行器ID过滤。
+<li> command-id - String - 是否必填：否 - （过滤条件）按命令ID过滤。
+<li> type - String - 是否必填：否 - （过滤条件）按执行器类型过滤。
+        :type Filters: list of Filter
+        :param Limit: 返回数量，默认为20，最大值为100。
+        :type Limit: int
+        :param Offset: 偏移量，默认为0。
+        :type Offset: int
+        """
+        self.InvokerIds = None
+        self.Filters = None
+        self.Limit = None
+        self.Offset = None
+
+
+    def _deserialize(self, params):
+        self.InvokerIds = params.get("InvokerIds")
+        if params.get("Filters") is not None:
+            self.Filters = []
+            for item in params.get("Filters"):
+                obj = Filter()
+                obj._deserialize(item)
+                self.Filters.append(obj)
+        self.Limit = params.get("Limit")
+        self.Offset = params.get("Offset")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class DescribeInvokersResponse(AbstractModel):
+    """DescribeInvokers返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param TotalCount: 满足条件的执行器数量。
+        :type TotalCount: int
+        :param InvokerSet: 执行器信息。
+        :type InvokerSet: list of Invoker
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.TotalCount = None
+        self.InvokerSet = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.TotalCount = params.get("TotalCount")
+        if params.get("InvokerSet") is not None:
+            self.InvokerSet = []
+            for item in params.get("InvokerSet"):
+                obj = Invoker()
+                obj._deserialize(item)
+                self.InvokerSet.append(obj)
+        self.RequestId = params.get("RequestId")
+
+
 class DescribeRegionsRequest(AbstractModel):
     """DescribeRegions请求参数结构体
 
@@ -631,7 +894,7 @@ class DescribeRegionsResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param TotalCount: 地域数量
         :type TotalCount: int
         :param RegionSet: 地域信息列表
@@ -655,6 +918,88 @@ class DescribeRegionsResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class DisableInvokerRequest(AbstractModel):
+    """DisableInvoker请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param InvokerId: 待停止的执行器ID。
+        :type InvokerId: str
+        """
+        self.InvokerId = None
+
+
+    def _deserialize(self, params):
+        self.InvokerId = params.get("InvokerId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class DisableInvokerResponse(AbstractModel):
+    """DisableInvoker返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.RequestId = params.get("RequestId")
+
+
+class EnableInvokerRequest(AbstractModel):
+    """EnableInvoker请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param InvokerId: 待启用的执行器ID。
+        :type InvokerId: str
+        """
+        self.InvokerId = None
+
+
+    def _deserialize(self, params):
+        self.InvokerId = params.get("InvokerId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class EnableInvokerResponse(AbstractModel):
+    """EnableInvoker返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.RequestId = params.get("RequestId")
+
+
 class Filter(AbstractModel):
     """>描述键值对过滤器，用于条件过滤查询。例如过滤ID、名称、状态等
     > * 若存在多个`Filter`时，`Filter`间的关系为逻辑与（`AND`）关系。
@@ -672,7 +1017,7 @@ class Filter(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Name: 需要过滤的字段。
         :type Name: str
         :param Values: 字段的过滤值。
@@ -700,7 +1045,7 @@ class Invocation(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param InvocationId: 执行活动ID。
         :type InvocationId: str
         :param CommandId: 命令ID。
@@ -735,6 +1080,14 @@ class Invocation(AbstractModel):
         :type Username: str
         :param InvocationSource: 调用来源。
         :type InvocationSource: str
+        :param CommandContent: base64编码的命令内容
+        :type CommandContent: str
+        :param CommandType: 命令类型
+        :type CommandType: str
+        :param Timeout: 执行命令过期时间， 单位秒
+        :type Timeout: int
+        :param WorkingDirectory: 执行命令的工作路径
+        :type WorkingDirectory: str
         """
         self.InvocationId = None
         self.CommandId = None
@@ -750,6 +1103,10 @@ class Invocation(AbstractModel):
         self.InstanceKind = None
         self.Username = None
         self.InvocationSource = None
+        self.CommandContent = None
+        self.CommandType = None
+        self.Timeout = None
+        self.WorkingDirectory = None
 
 
     def _deserialize(self, params):
@@ -772,6 +1129,10 @@ class Invocation(AbstractModel):
         self.InstanceKind = params.get("InstanceKind")
         self.Username = params.get("Username")
         self.InvocationSource = params.get("InvocationSource")
+        self.CommandContent = params.get("CommandContent")
+        self.CommandType = params.get("CommandType")
+        self.Timeout = params.get("Timeout")
+        self.WorkingDirectory = params.get("WorkingDirectory")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -787,7 +1148,7 @@ class InvocationTask(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param InvocationId: 执行活动ID。
         :type InvocationId: str
         :param InvocationTaskId: 执行任务ID。
@@ -799,9 +1160,10 @@ class InvocationTask(AbstractModel):
 <li> DELIVERING：下发中
 <li> DELIVER_DELAYED：延时下发 
 <li> DELIVER_FAILED：下发失败
+<li> START_FAILED：命令启动失败
 <li> RUNNING：命令运行中
 <li> SUCCESS：命令成功
-<li> FAILED：命令失败
+<li> FAILED：命令执行失败，执行完退出码不为 0
 <li> TIMEOUT：命令超时
 <li> TASK_TIMEOUT：执行任务超时
         :type TaskStatus: str
@@ -872,7 +1234,7 @@ class InvocationTaskBasicInfo(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param InvocationTaskId: 执行任务ID。
         :type InvocationTaskId: str
         :param TaskStatus: 执行任务状态。取值范围：
@@ -913,7 +1275,7 @@ class InvokeCommandRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param CommandId: 待触发的命令ID。
         :type CommandId: str
         :param InstanceIds: 待执行命令的实例ID列表，上限100。
@@ -931,6 +1293,13 @@ key为自定义参数名称，value为该参数的默认取值。kv均为字符
         :type WorkingDirectory: str
         :param Timeout: 命令超时时间，取值范围[1, 86400]。默认以Command配置的Timeout执行。
         :type Timeout: int
+        :param OutputCOSBucketUrl: 指定日志上传的cos bucket 地址，必须以https开头，如 https://BucketName-123454321.cos.ap-beijing.myqcloud.com。
+        :type OutputCOSBucketUrl: str
+        :param OutputCOSKeyPrefix: 指定日志在cos bucket中的目录，目录命名有如下规则：
+1. 可用数字、中英文和可见字符的组合，长度最多为60。
+2. 用 / 分割路径，可快速创建子目录。
+3. 不允许连续 / ；不允许以 / 开头；不允许以..作为文件夹名称。
+        :type OutputCOSKeyPrefix: str
         """
         self.CommandId = None
         self.InstanceIds = None
@@ -938,6 +1307,8 @@ key为自定义参数名称，value为该参数的默认取值。kv均为字符
         self.Username = None
         self.WorkingDirectory = None
         self.Timeout = None
+        self.OutputCOSBucketUrl = None
+        self.OutputCOSKeyPrefix = None
 
 
     def _deserialize(self, params):
@@ -947,6 +1318,8 @@ key为自定义参数名称，value为该参数的默认取值。kv均为字符
         self.Username = params.get("Username")
         self.WorkingDirectory = params.get("WorkingDirectory")
         self.Timeout = params.get("Timeout")
+        self.OutputCOSBucketUrl = params.get("OutputCOSBucketUrl")
+        self.OutputCOSKeyPrefix = params.get("OutputCOSKeyPrefix")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -962,7 +1335,7 @@ class InvokeCommandResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param InvocationId: 执行活动ID。
         :type InvocationId: str
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -977,13 +1350,120 @@ class InvokeCommandResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class Invoker(AbstractModel):
+    """执行器信息。
+
+    """
+
+    def __init__(self):
+        r"""
+        :param InvokerId: 执行器ID。
+        :type InvokerId: str
+        :param Name: 执行器名称。
+        :type Name: str
+        :param Type: 执行器类型。
+        :type Type: str
+        :param CommandId: 命令ID。
+        :type CommandId: str
+        :param Username: 用户名。
+        :type Username: str
+        :param Parameters: 自定义参数。
+        :type Parameters: str
+        :param InstanceIds: 实例ID列表。
+        :type InstanceIds: list of str
+        :param Enable: 执行器是否启用。
+        :type Enable: bool
+        :param ScheduleSettings: 执行器周期计划。周期执行器会返回此字段。
+注意：此字段可能返回 null，表示取不到有效值。
+        :type ScheduleSettings: :class:`tencentcloud.tat.v20201028.models.ScheduleSettings`
+        :param CreatedTime: 创建时间。
+        :type CreatedTime: str
+        :param UpdatedTime: 修改时间。
+        :type UpdatedTime: str
+        """
+        self.InvokerId = None
+        self.Name = None
+        self.Type = None
+        self.CommandId = None
+        self.Username = None
+        self.Parameters = None
+        self.InstanceIds = None
+        self.Enable = None
+        self.ScheduleSettings = None
+        self.CreatedTime = None
+        self.UpdatedTime = None
+
+
+    def _deserialize(self, params):
+        self.InvokerId = params.get("InvokerId")
+        self.Name = params.get("Name")
+        self.Type = params.get("Type")
+        self.CommandId = params.get("CommandId")
+        self.Username = params.get("Username")
+        self.Parameters = params.get("Parameters")
+        self.InstanceIds = params.get("InstanceIds")
+        self.Enable = params.get("Enable")
+        if params.get("ScheduleSettings") is not None:
+            self.ScheduleSettings = ScheduleSettings()
+            self.ScheduleSettings._deserialize(params.get("ScheduleSettings"))
+        self.CreatedTime = params.get("CreatedTime")
+        self.UpdatedTime = params.get("UpdatedTime")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class InvokerRecord(AbstractModel):
+    """执行器执行记录。
+
+    """
+
+    def __init__(self):
+        r"""
+        :param InvokerId: 执行器ID。
+        :type InvokerId: str
+        :param InvokeTime: 执行时间。
+        :type InvokeTime: str
+        :param Reason: 执行原因。
+        :type Reason: str
+        :param InvocationId: 命令执行ID。
+        :type InvocationId: str
+        :param Result: 触发结果。
+        :type Result: str
+        """
+        self.InvokerId = None
+        self.InvokeTime = None
+        self.Reason = None
+        self.InvocationId = None
+        self.Result = None
+
+
+    def _deserialize(self, params):
+        self.InvokerId = params.get("InvokerId")
+        self.InvokeTime = params.get("InvokeTime")
+        self.Reason = params.get("Reason")
+        self.InvocationId = params.get("InvocationId")
+        self.Result = params.get("Result")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class ModifyCommandRequest(AbstractModel):
     """ModifyCommand请求参数结构体
 
     """
 
     def __init__(self):
-        """
+        r"""
         :param CommandId: 命令ID。
         :type CommandId: str
         :param CommandName: 命令名称。名称仅支持中文、英文、数字、下划线、分隔符"-"、小数点，最大长度不能超60个字节。
@@ -1008,6 +1488,13 @@ key为自定义参数名称，value为该参数的默认取值。kv均为字符
         :param Username: 在 CVM 或 Lighthouse 实例中执行命令的用户名称。
 使用最小权限执行命令是权限管理的最佳实践，建议您以普通用户身份执行云助手命令。默认情况下，在Linux实例中以root用户执行命令。
         :type Username: str
+        :param OutputCOSBucketUrl: 指定日志上传的cos bucket 地址，必须以https开头，如 https://BucketName-123454321.cos.ap-beijing.myqcloud.com。
+        :type OutputCOSBucketUrl: str
+        :param OutputCOSKeyPrefix: 指定日志在cos bucket中的目录，目录命名有如下规则：
+1. 可用数字、中英文和可见字符的组合，长度最多为60。
+2. 用 / 分割路径，可快速创建子目录。
+3. 不允许连续 / ；不允许以 / 开头；不允许以..作为文件夹名称。
+        :type OutputCOSKeyPrefix: str
         """
         self.CommandId = None
         self.CommandName = None
@@ -1018,6 +1505,8 @@ key为自定义参数名称，value为该参数的默认取值。kv均为字符
         self.Timeout = None
         self.DefaultParameters = None
         self.Username = None
+        self.OutputCOSBucketUrl = None
+        self.OutputCOSKeyPrefix = None
 
 
     def _deserialize(self, params):
@@ -1030,6 +1519,8 @@ key为自定义参数名称，value为该参数的默认取值。kv均为字符
         self.Timeout = params.get("Timeout")
         self.DefaultParameters = params.get("DefaultParameters")
         self.Username = params.get("Username")
+        self.OutputCOSBucketUrl = params.get("OutputCOSBucketUrl")
+        self.OutputCOSKeyPrefix = params.get("OutputCOSKeyPrefix")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -1045,7 +1536,78 @@ class ModifyCommandResponse(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
         """
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.RequestId = params.get("RequestId")
+
+
+class ModifyInvokerRequest(AbstractModel):
+    """ModifyInvoker请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param InvokerId: 待修改的执行器ID。
+        :type InvokerId: str
+        :param Name: 待修改的执行器名称。
+        :type Name: str
+        :param Type: 执行器类型，当前仅支持周期类型执行器，取值：`SCHEDULE` 。
+        :type Type: str
+        :param CommandId: 待修改的命令ID。
+        :type CommandId: str
+        :param Username: 待修改的用户名。
+        :type Username: str
+        :param Parameters: 待修改的自定义参数。
+        :type Parameters: str
+        :param InstanceIds: 待修改的实例ID列表。列表长度上限100。
+        :type InstanceIds: list of str
+        :param ScheduleSettings: 待修改的周期执行器设置。
+        :type ScheduleSettings: :class:`tencentcloud.tat.v20201028.models.ScheduleSettings`
+        """
+        self.InvokerId = None
+        self.Name = None
+        self.Type = None
+        self.CommandId = None
+        self.Username = None
+        self.Parameters = None
+        self.InstanceIds = None
+        self.ScheduleSettings = None
+
+
+    def _deserialize(self, params):
+        self.InvokerId = params.get("InvokerId")
+        self.Name = params.get("Name")
+        self.Type = params.get("Type")
+        self.CommandId = params.get("CommandId")
+        self.Username = params.get("Username")
+        self.Parameters = params.get("Parameters")
+        self.InstanceIds = params.get("InstanceIds")
+        if params.get("ScheduleSettings") is not None:
+            self.ScheduleSettings = ScheduleSettings()
+            self.ScheduleSettings._deserialize(params.get("ScheduleSettings"))
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class ModifyInvokerResponse(AbstractModel):
+    """ModifyInvoker返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
@@ -1062,7 +1624,7 @@ class PreviewReplacedCommandContentRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Parameters: 本次预览采用的自定义参数。字段类型为 json encoded string，如：{\"varA\": \"222\"}。
 key 为自定义参数名称，value 为该参数的取值。kv 均为字符串型。
 自定义参数最多 20 个。
@@ -1100,7 +1662,7 @@ class PreviewReplacedCommandContentResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param ReplacedContent: 自定义参数替换后的，经Base64编码的命令内容。
         :type ReplacedContent: str
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -1121,7 +1683,7 @@ class RegionInfo(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Region: 地域名称，例如，ap-guangzhou
         :type Region: str
         :param RegionName: 地域描述，例如: 广州
@@ -1153,7 +1715,7 @@ class RunCommandRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Content: Base64编码后的命令内容，长度不可超过64KB。
         :type Content: str
         :param InstanceIds: 待执行命令的实例ID列表，上限100。支持实例类型：
@@ -1196,6 +1758,13 @@ key为自定义参数名称，value为该参数的默认取值。kv均为字符
         :param Username: 在 CVM 或 Lighthouse 实例中执行命令的用户名称。
 使用最小权限执行命令是权限管理的最佳实践，建议您以普通用户身份执行云助手命令。默认情况下，在Linux实例中以root用户执行命令。
         :type Username: str
+        :param OutputCOSBucketUrl: 指定日志上传的cos bucket 地址，必须以https开头，如 https://BucketName-123454321.cos.ap-beijing.myqcloud.com。
+        :type OutputCOSBucketUrl: str
+        :param OutputCOSKeyPrefix: 指定日志在cos bucket中的目录，目录命名有如下规则：
+1. 可用数字、中英文和可见字符的组合，长度最多为60。
+2. 用 / 分割路径，可快速创建子目录。
+3. 不允许连续 / ；不允许以 / 开头；不允许以..作为文件夹名称。
+        :type OutputCOSKeyPrefix: str
         """
         self.Content = None
         self.InstanceIds = None
@@ -1210,6 +1779,8 @@ key为自定义参数名称，value为该参数的默认取值。kv均为字符
         self.Parameters = None
         self.Tags = None
         self.Username = None
+        self.OutputCOSBucketUrl = None
+        self.OutputCOSKeyPrefix = None
 
 
     def _deserialize(self, params):
@@ -1231,6 +1802,8 @@ key为自定义参数名称，value为该参数的默认取值。kv均为字符
                 obj._deserialize(item)
                 self.Tags.append(obj)
         self.Username = params.get("Username")
+        self.OutputCOSBucketUrl = params.get("OutputCOSBucketUrl")
+        self.OutputCOSKeyPrefix = params.get("OutputCOSKeyPrefix")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -1246,7 +1819,7 @@ class RunCommandResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param CommandId: 命令ID。
         :type CommandId: str
         :param InvocationId: 执行活动ID。
@@ -1265,13 +1838,47 @@ class RunCommandResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class ScheduleSettings(AbstractModel):
+    """周期执行器设置。
+
+    """
+
+    def __init__(self):
+        r"""
+        :param Policy: 执行策略：
+<br><li>ONCE：单次执行
+<br><li>RECURRENCE：周期执行
+        :type Policy: str
+        :param Recurrence: 触发 Crontab 表达式。Policy 为 RECURRENCE 时，需要指定此字段。Crontab 按北京时间解析。
+        :type Recurrence: str
+        :param InvokeTime: 执行器下次执行时间。Policy 为 ONCE 时，需要指定此字段。
+        :type InvokeTime: str
+        """
+        self.Policy = None
+        self.Recurrence = None
+        self.InvokeTime = None
+
+
+    def _deserialize(self, params):
+        self.Policy = params.get("Policy")
+        self.Recurrence = params.get("Recurrence")
+        self.InvokeTime = params.get("InvokeTime")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class Tag(AbstractModel):
     """标签
 
     """
 
     def __init__(self):
-        """
+        r"""
         :param Key: 标签键。
         :type Key: str
         :param Value: 标签值。
@@ -1299,7 +1906,7 @@ class TaskResult(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param ExitCode: 命令执行ExitCode。
         :type ExitCode: int
         :param Output: Base64编码后的命令输出。最大长度24KB。
